==> mongodb-src-r4.2.2.tar.gz: mongodb-src-r4.2.2/src/mongo/db/catalog/coll_mod.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/base/status.h"
#include "mongo/base/status_with.h"
#include "mongo/db/catalog/collection_options.h"

namespace mongo {
class BSONObj;
class BSONObjBuilder;
class Collection;
class NamespaceString;
class OperationContext;

/**
 * Adds UUIDs to all replicated collections of all databases if they do not already have UUIDs. If
 * this function is not necessary for SERVER-33247, it can be removed.
 */
void addCollectionUUIDs(OperationContext* opCtx);

/**
 * Performs the collection modification described in "cmdObj" on the collection "ns".
 */
Status collMod(OperationContext* opCtx,
               const NamespaceString& ns,
               const BSONObj& cmdObj,
               BSONObjBuilder* result);

/**
 * Applies the collMod operation and optionally updates formatVersion of unique indexes belonging
 * to collection "nss".
 */
Status collModWithUpgrade(OperationContext* opCtx,
                          const NamespaceString& nss,
                          const BSONObj& cmdObj);

/*
 * Updates the unique indexes to timestamp safe unique index format on setFCV=4.2. It also updates
 * non-replicated unique indexes indirectly by calling updateNonReplicatedUniqueIndexes().
 */
void updateUniqueIndexesOnUpgrade(OperationContext* opCtx);

/*
 * Updates non-replicated unique indexes to timestamp safe unique index format.
 */
Status updateNonReplicatedUniqueIndexes(OperationContext* opCtx);
}  // namespace mongo

==> mongodb-src-r5.0.5.tar.gz: mongodb-src-r5.0.5/src/mongo/db/catalog/coll_mod.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/base/status.h"
#include "mongo/base/status_with.h"
#include "mongo/db/catalog/collection_options.h"

namespace mongo {
class BSONObj;
class BSONObjBuilder;
class Collection;
class CollectionPtr;
class NamespaceString;
class OperationContext;

/**
 * Adds UUIDs to all replicated collections of all databases if they do not already have UUIDs. If
 * this function is not necessary for SERVER-33247, it can be removed.
 */
void addCollectionUUIDs(OperationContext* opCtx);

/**
 * Performs the collection modification described in "cmdObj" on the collection "ns".
 */
Status collMod(OperationContext* opCtx,
               const NamespaceString& ns,
               const BSONObj& cmdObj,
               BSONObjBuilder* result);

}  // namespace mongo
